@@ -2,13 +2,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 
-from trytond.pool import Pool, PoolMeta
+from trytond.pool import Pool
 from trytond.report import Report
-from datetime import date
-
-
-__all__ = ['ReportOdt']
-__metaclass__ = PoolMeta
 
 
 class ReportOdt(Report):
@@ -18,9 +13,12 @@ class ReportOdt(Report):
     def execute(cls, ids, data):
         """ edit filename
         """
-        ExpObj = Pool().get(data['model'])(data['id'])
+        pool = Pool()
+        IrDate = pool.get('ir.date')
+        ExpObj = pool.get(data['model'])(data['id'])
+        
         (ext1, cont1, dirprint, titel) = super(ReportOdt, cls).execute(ids, data)
-        titel = '%s-note-%s' % (date.today().strftime('%Y%m%d'), ExpObj.name[:15])
+        titel = '%s-note-%s' % (IrDate.today().strftime('%Y%m%d'), ExpObj.name[:15])
         return (ext1, cont1, dirprint, titel)
 
     @classmethod
